@@ -117,11 +117,19 @@ def test_score(h):
     勉強時間に対する，テストの点数を返す
     100点満点，10時間で限界効用逓減によって下がって行く。
     """
+    if h > 20:
+        h = 20
     score = int(np.poly1d(coef)(h))+1
+    if score > 100:
+        score = 100
     return score
 
 
 def test_score2(h, i):
+    if h > 20:
+        h = 20
     score = int(np.poly1d(coef)(h))+1-20
     score = score*(i/100)+20
+    if score > 100:
+        score = 100
     return score
\ No newline at end of file
